module.exports = {
  extends: [
    'plugin:import/recommended',
    'plugin:ordered-imports/recommended',
    'plugin:promise/recommended',
    'prettier',
  ],
  env: {
    node: true,
  },
  plugins: [
    'eslint-comments',
    'import',
    'ordered-imports',
    'promise',
    'unicorn',
  ],
  rules: {
    /**
     * Global style rules
     */
    'max-len': [
      'error',
      {
        code: 80,
        ignoreComments: true,
        ignoreRegExpLiterals: true,
        ignoreStrings: true,
        ignoreTemplateLiterals: true,
        ignoreTrailingComments: true,
        ignoreUrls: true,
        tabWidth: 2,
      },
    ],
    'no-console': process.env.NODE_ENV === 'production' ? 'error' : 'off',
    'no-debugger': process.env.NODE_ENV === 'production' ? 'error' : 'off',
    'no-void': ['error', { allowAsStatement: true }],
    'object-curly-spacing': [2, 'always'],
    semi: ['error', 'always'],
    'unicorn/no-array-for-each': 'warn',
    'unicorn/no-null': 'warn',
    'unicorn/numeric-separators-style': 'warn',
    'unicorn/prefer-node-protocol': 'warn',
    'unicorn/prevent-abbreviations': [
      'error',
      {
        allowList: {
          args: true,
        },
      },
    ],
  },
  overrides: [
    {
      /**
       * Relax rules in configuration files
       */
      files: [
        '**/.eslintrc.js',
        '**/commitlint.config.js',
        '**/jest.config.js',
        '**/jest.setup.js',
        '**/.stylelintrc.js',
        '**/webpack.config.js',
        '**/webpack.config.*.js',
      ],
      rules: {
        '@typescript-eslint/no-floating-promises': 'off',
        '@typescript-eslint/no-unsafe-call': 'off',
        '@typescript-eslint/no-unsafe-assignment': 'off',
        '@typescript-eslint/no-var-requires': 'off',
        'node/no-extraneous-require': 'off',
        'node/no-unpublished-require': 'off',
        'prefer-const': 'off',
        'unicorn/prefer-module': 'off',
      },
    },
  ],
};
